@@ -2,6 +2,9 @@ import requests
 from getpass import getpass
 from termcolor import cprint
 
+import webbrowser
+webbrowser.open('http://google.co.kr', new=2)
+
 def login():
     
     print("\t\t\t\t\t"+"-"*33)
@@ -17,6 +20,8 @@ def login():
 
     if data == {}:
         cprint("Esa cuenta no existe intentalo otra vez", "red")
-        exit(0)
+        si_no = input("\n¿Quieres crearte una? [s/n] :: ")
+        webbrowser.open('http://127.0.0.1:5000/login', new=2) if input == "s" else exit(0)
+        return login()
 
     return data
